Crate simple_string_patterns

Crate simple_string_patterns 

Re-exports

pub use crate::matches::*;

Modules

matches

Enums

CharType
Methods to strip or filter character types within strings and to extract integers or floats Defines character group types with special custom types (Char, Chars, Range, Between)

Traits

CharGroupMatch
Methods to strip or filter character types within strings and to extract integers or floats Methods to validate strings with character classes
IsNumeric
Methods to strip or filter character types within strings and to extract integers or floats Method to check if the string may be parsed to an integer or float
StripCharacters
Methods to strip or filter character types within strings and to extract integers or floats Set of methods to strip unwanted characters by type or extract vectors of numeric strings, integers or floats