pub enum CharType<'a> {
}Expand description
Methods to strip or filter character types within strings and to extract integers or floats Defines character group types with special custom types (Char, Chars, Range, Between)
Variants
Any
DecDigit
Digit(u32)
Numeric
AlphaNum
Upper
Lower
Alpha
Spaces
Punctuation
Char(char)
Chars(&'a [char])
Range(Range<char>)
Between(char, char)
Implementations