Module matches

Module matches 

Traits

MatchOccurrences
Return the indices of all ocurrences of a string
SimplContainsType
Test if character set (CharType) is in the string
SimpleMatch
Regex-free matcher methods for common use cases There are no plain and _cs-suffixed variants because the standard starts_with(pat: &str), contains(pat: &str) and ends_with(pat: &str) methods meet those needs