SimplContainsType

Trait SimplContainsType 

pub trait SimplContainsType
where Self: SimpleMatch,
{ // Required methods fn contains_type(&self, char_type: CharType<'_>) -> bool; fn contains_types(&self, char_types: &[CharType<'_>]) -> bool; fn starts_with_type(&self, char_type: CharType<'_>) -> bool; fn starts_with_types(&self, char_types: &[CharType<'_>]) -> bool; fn ends_with_type(&self, char_type: CharType<'_>) -> bool; fn ends_with_types(&self, char_types: &[CharType<'_>]) -> bool; }
Test if character set (CharType) is in the string

Required Methods

fn contains_type(&self, char_type: CharType<'_>) -> bool

contains characters in the specified set

fn contains_types(&self, char_types: &[CharType<'_>]) -> bool

contains characters in the specified sets

fn starts_with_type(&self, char_type: CharType<'_>) -> bool

starts with one or more characters in the specified set

fn starts_with_types(&self, char_types: &[CharType<'_>]) -> bool

starts with one or more characters in the specified set

fn ends_with_type(&self, char_type: CharType<'_>) -> bool

ends with one or more characters in the specified sets

fn ends_with_types(&self, char_types: &[CharType<'_>]) -> bool

ends with one or more characters in the specified sets

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors