CharGroupMatch

Trait CharGroupMatch 

pub trait CharGroupMatch {
    // Required methods
    fn has_digits(&self) -> bool;
    fn has_digits_radix(&self, radix: u8) -> bool;
    fn has_alphanumeric(&self) -> bool;
    fn has_alphabetic(&self) -> bool;
    fn is_digits_only(&self) -> bool;
    fn is_digits_only_radix(&self, radix: u8) -> bool;
}
Methods to strip or filter character types within strings and to extract integers or floats Methods to validate strings with character classes

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> CharGroupMatch for T
where T: AsRef<str>,