Traits
- Match
Occurrences - Return the indices of all ocurrences of a string
- Simpl
Contains Type - Test if character set (CharType) is in the string
- Simple
Match - Regex-free matcher methods for common use cases There are no plain and _cs-suffixed variants because the standard starts_with(pat: &str), contains(pat: &str) and ends_with(pat: &str) methods meet those needs