pub trait SimpleMatch {
// Required methods
fn equals_ci(&self, pattern: &str) -> bool;
fn equals_ci_alphanum(&self, pattern: &str) -> bool;
fn starts_with_ci(&self, pattern: &str) -> bool;
fn starts_with_ci_alphanum(&self, pattern: &str) -> bool;
fn ends_with_ci(&self, pattern: &str) -> bool;
fn ends_with_ci_alphanum(&self, pattern: &str) -> bool;
fn contains_ci(&self, pattern: &str) -> bool;
fn contains_ci_alphanum(&self, pattern: &str) -> bool;
}Expand description
Regex-free matcher methods for common use cases There are no plain and _cs-suffixed variants because the standard starts_with(pat: &str), contains(pat: &str) and ends_with(pat: &str) methods meet those needs
Required Methods
Sourcefn equals_ci_alphanum(&self, pattern: &str) -> bool
fn equals_ci_alphanum(&self, pattern: &str) -> bool
Matches the the plain Latin letters [a-z] and numerals [0=9] in the string in case-insensitive mode
Sourcefn starts_with_ci(&self, pattern: &str) -> bool
fn starts_with_ci(&self, pattern: &str) -> bool
Starts with a pattern in case-insensitive mode
Sourcefn starts_with_ci_alphanum(&self, pattern: &str) -> bool
fn starts_with_ci_alphanum(&self, pattern: &str) -> bool
Starts with a case-insensitive alphanumeric sequence, ignoring any other characters in the pattern or sample string
Sourcefn ends_with_ci(&self, pattern: &str) -> bool
fn ends_with_ci(&self, pattern: &str) -> bool
Ends with a pattern in case-insensitive mode
Sourcefn ends_with_ci_alphanum(&self, pattern: &str) -> bool
fn ends_with_ci_alphanum(&self, pattern: &str) -> bool
Ends with a case-insensitive alphanumeric sequence, ignoring any other characters in the pattern or sample string
Sourcefn contains_ci(&self, pattern: &str) -> bool
fn contains_ci(&self, pattern: &str) -> bool
Contains a pattern in case-insensitive mode
Sourcefn contains_ci_alphanum(&self, pattern: &str) -> bool
fn contains_ci_alphanum(&self, pattern: &str) -> bool
Contains a case-insensitive alphanumeric sequence, ignoring any other characters in the pattern or sample string
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".