pub trait IsNumeric {
// Required method
fn is_numeric(&self) -> bool;
}Expand description
Methods to strip or filter character types within strings and to extract integers or floats Method to check if the string may be parsed to an integer or float
Required Methods
Sourcefn is_numeric(&self) -> bool
fn is_numeric(&self) -> bool
strict check on a numeric string before using .parse::<T>()
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".